package com.gyee.wisdom.xfai.net3.mapper;

import com.gyee.wisdom.xfai.net3.model.StateTransitionRates;
import com.gyee.wisdom.xfai.net3.model.XFCommand;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.Date;
import java.util.List;

/**
 * @author caoxin
 * @date 2021-07-2021/7/6-19:04
 */
@Mapper
public interface ProjectPlanMapper {

    long getDWKPlan(XFCommand command);

    long getXSPlan(XFCommand command);

    long getMCHPlan(XFCommand command);

    long getMHSPlan(XFCommand command);

    long getNSSPlan(XFCommand command);

    long getPLPlan(XFCommand command);

    long getQSPlan(XFCommand command);

    long getSBQPlan(XFCommand command);

    long getXHPlan(XFCommand command);

    List<Long> selectAllTimes(@Param("date")String date);

    List<Long> selectAllActual(@Param("date")String date);

    List<Long> selectFWTimes(@Param("date") String date);

    List<Long> selectAllFWTimes(@Param("date") String date);

    List<Long> selectActualConvert(@Param("date") String date);

    List<Long> selectFullConvert(@Param("date") String date);
}
